## ABOUT

This is a mini deep learning framework created by Krasjet

## Features

+ Define Dynamic Computing Graph
+ Define Neural Network Operator
+ Define Linear, Sigmoid, L2_loss
+ Auto-Diff Computing
+ Auto-Feedforward and Backward

## Remain

+ Classification
+ Cross-Entropy
+ CNN, RNN

## Connection

+ WeChat: Krasjet01
+ Mail: krasjet.ziping@gmail.com